@@ -55,7 +55,8 @@ class ALFA_Utils:
         if self.save_ground_truth:
             _, file_ext = os.path.splitext(image_file_name)
             image_file_json = image_file_name.replace(file_ext, '.json')
-            results_file = os.path.join(self.alfa_results_dir, image_file_json)
+            results_file = os.path.join(
+                self.__alfa_results_dir, image_file_json)
             with open(results_file, 'w') as f:
                 json.dump(ai4adas_object, f, ensure_ascii=False)
 
@@ -72,13 +73,13 @@ class ALFA_Utils:
 
         if self.save_alfa:
             results_file_name = os.path.join(
-                self.alfa_results_dir, alfa_json_name)
+                self.__alfa_results_dir, alfa_json_name)
             with open(f"{results_file_name}.json", 'w') as f:
                 json.dump(ai4adas_alfa_detections, f, ensure_ascii=False)
 
             if os.path.isdir(self.__alfa_path_detections):
                 shutil.copy(f"{results_file_name}.json",
-                            self.alfa_path_detections)
+                            self.__alfa_path_detections)
 
             print(
                 f'\nWriting {alfa_json_name}.json for ALFA within {self.__alfa_results_dir} folder...')
